@@ -208,7 +208,7 @@ QByteArray Content::assembleHeaders()
 {
     Q_D(Content);
     QByteArray newHead;
-    foreach (const Headers::Base *h, d->headers) {
+    for (const Headers::Base *h : qAsConst(d->headers)) {
         if (!h->isEmpty()) {
             newHead += h->as7BitString() + '\n';
         }
@@ -307,7 +307,7 @@ QByteArray Content::encodedBody()
         }
 
         //add all (encoded) contents separated by boundaries
-        foreach (Content *c, d->multipartContents) {
+        for (Content *c : qAsConst(d->multipartContents)) {
             e += boundary + '\n';
             e += c->encodedContent(false);    // don't convert LFs here, we do that later!!!!!
         }
@@ -453,7 +453,7 @@ QVector<Content*> Content::attachments()
     if (ct && ct->isMultipart() && !ct->isSubtype("related") && !ct->isSubtype("alternative")) {
         const QVector<Content*> contentsList = contents();
         result.reserve(contentsList.count());
-        Q_FOREACH (Content *child, contentsList) {
+        for (Content *child : contentsList) {
             if (isAttachment(child))
                 result.push_back(child);
             else
@@ -621,7 +621,7 @@ Headers::Base *Content::headerByType(const char *type) const
 {
     Q_ASSERT(type  && *type);
 
-    foreach (Headers::Base *h, d_ptr->headers) {
+    for (Headers::Base *h : qAsConst(d_ptr->headers)) {
         if (h->is(type)) {
             return h; // Found.
         }
@@ -636,7 +636,7 @@ QVector<Headers::Base*> Content::headersByType(const char *type) const
 
     QVector<Headers::Base*> result;
 
-    foreach (Headers::Base *h, d_ptr->headers) {
+    for (Headers::Base *h : qAsConst(d_ptr->headers)) {
         if (h->is(type)) {
             result << h;
         }
@@ -1036,7 +1036,7 @@ bool ContentPrivate::parseMultipart(Content *q)
     Q_ASSERT(multipartContents.isEmpty());
     body.clear();
     const auto parts = mpp.parts();
-    foreach (const QByteArray &part, parts) {
+    for (const QByteArray &part : parts) {
         Content *c = new Content(q);
         c->setContent(part);
         c->setFrozen(frozen);
